# FACT Sea and Inland Water Ports
Sea and inland waters ports location and tonnage in Europe and US.

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Fdata%2FFACT_mine?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2F4PJDM-blue?style=flat)](https://doi.org/10.17605/OSF.IO/4PJDM)
[![Data License](https://img.shields.io/badge/data-CC%20BY%204.0-green)](https://creativecommons.org/licenses/by/4.0/legalcode.txt)

---

## Use
1. Through the command line:
```bash
docker pull registry.git.nilu.no/fact/data/fact_ports:latest
docker run -t -i --name fact_ports -e MARIADB_DATABASE=FACT_ports -e MYSQL_ROOT_PASSWORD=devops -p 3312:3306 -d registry.git.nilu.no/fact/data/fact_ports:0.1
```
2. Through a docker-compose file:
```yaml
version: '3.8'

services:
  fact_ports:
    image: registry.git.nilu.no/fact/data/fact_ports:latest
    container_name: fact_ports
    environment:
      MARIADB_DATABASE: FACT_ports
      MYSQL_ROOT_PASSWORD: devops
    ports:
      - "3312:3306"
    restart: unless-stopped
```
which could be executed with `docker-compose up fact_ports -d`.

The container makes available a MariaDB instance with the full database on sea and inland waters ports **FACT_ports**. It is reachable on port 3312 of the localhost and the root password is 'devops'.

---
## Specifications
```
Table            |Size (MB)|Rows (#)|
-----------------+---------+--------+
eu_ports_2009_geo|     0.30|    2201|
eu_ports_2013_geo|     0.34|    2440|
eu_tonnage       |     0.58|   10675|
geometry_columns |     0.02|       3|
spatial_ref_sys  |     0.02|       2|
us_ports_geo     |     0.05|     150|
```

![tables schema](FACT_ports.png "Tables in DB")

Column Year in eu_ports is from 1997 to 2023.

**All spatial objects are converted to EPSG:4326**

---
## Notes
**Europe**
Ports, worldwide but US not well covered (use field PORT_ID for identification):
- https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/transport-networks

Tonnage (in thousand tonnes, quarterly, total values)
- [DOI: 10.2908/MAR_GO_QM](https://doi.org/10.2908/MAR_GO_QM)

**US**
The Principal Port dataset contains port codes, port names, geographic locations (longitude, latitude), and commodity tonnage summaries (total tons, domestic, foreign, imports and exports):
- https://geodata.bts.gov/datasets/usdot::principal-ports/about

---
## Author
Riccardo Boero - ribo@nilu.no

## Licenses
All the code and the resulting docker images in this project are subject to:
- [GNU General Public License v2](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

The data is released under: 
- [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

The input data is licensed as:
- [Eurostat data](https://ec.europa.eu/eurostat/about-us/policies/copyright)
- [US BTS data - CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)


## Citation
- Boero, Riccardo. 2024. “FACT Data: Sea and Inland Waters.” OSF. [doi:10.17605/OSF.IO/4PJDM](https://doi.org/10.17605/OSF.IO/4PJDM). 

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 

